"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSignals = void 0;

var _os = require("os");

var _core = require("./core.js");

var _realtime = require("./realtime.js");

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

// Retrieve list of know signals (including realtime) with information about
// them
var getSignals = function getSignals() {
  var realtimeSignals = (0, _realtime.getRealtimeSignals)();
  var signals = [].concat(_toConsumableArray(_core.SIGNALS), _toConsumableArray(realtimeSignals)).map(normalizeSignal);
  return signals;
}; // Normalize signal:
//  - `number`: signal numbers are OS-specific. This is taken into account by
//    `os.constants.signals`. However we provide a default `number` since some
//     signals are not defined for some OS.
//  - `forced`: set default to `false`
//  - `supported`: set value


exports.getSignals = getSignals;

var normalizeSignal = function normalizeSignal(_ref) {
  var name = _ref.name,
      defaultNumber = _ref.number,
      description = _ref.description,
      action = _ref.action,
      _ref$forced = _ref.forced,
      forced = _ref$forced === void 0 ? false : _ref$forced,
      standard = _ref.standard;
  var constantSignal = _os.constants.signals[name];
  var supported = constantSignal !== undefined;
  var number = supported ? constantSignal : defaultNumber;
  return {
    name: name,
    number: number,
    description: description,
    supported: supported,
    action: action,
    forced: forced,
    standard: standard
  };
};